@@ -29,17 +29,17 @@ class Product:
 class ProductCatalog:
     _url_path = "/product-catalog"
 
-    def __init__(self, code, products):
+    def __init__(self, code, products, **kwargs):
         self.code = code
         self.products = [Product(**product) for product in products]
 
     @classmethod
     def search(cls, code="", category="", lang="ca", product_code=""):
-        headers = {'Accept-Language': lang}
+        headers = {"Accept-Language": lang}
         response_data = Client().get(
             "{}".format(cls._url_path),
             params={"code": code, "categ": category, "product_code": product_code},
-            extra_headers=headers
+            extra_headers=headers,
         )
 
         pricelists = []
